# 🕳️🌀 DeepLeap - NPCs Unleashed in the Cloud

`DeepLeap` illustrates the lifelike nature of LLM entities, better known as agents.

Using the `deepleapio` package, users can quickly get started creating virtual fantasies, scenarios, and online conversations with their own characters.

🔗 Docs: https://www.deepleap.io/
